Package: NanoTube
Type: Package
Title: An Easy Pipeline for NanoString nCounter Data Analysis
Version: 1.16.0
Date: 2023-05-31
Authors@R: c(person("Caleb", "Class", email="cclass@butler.edu",
                  role = c("cre", "aut"), 
                  comment = c(ORCID = "0000-0003-3130-3613")),
             person("Caiden", "Lukan", role = "ctb"))
Depends: R (>= 4.1), Biobase, ggplot2, limma
Imports: fgsea, methods, reshape, stats, utils
Suggests: grid, kableExtra, knitr, NanoStringDiff, pheatmap, plotly,
        rlang, rmarkdown, ruv, RUVSeq, shiny, testthat, xlsx
VignetteBuilder: knitr
Description: NanoTube includes functions for the processing, quality control, 
    analysis, and visualization of NanoString nCounter data. Analysis functions
    include differential analysis and gene set analysis methods, as well as
    postprocessing steps to help understand the results. Additional functions
    are included to enable interoperability with other Bioconductor NanoString
    data analysis packages.
License: GPL-3 + file LICENSE
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.2.1
biocViews: Software, GeneExpression, DifferentialExpression,
        QualityControl
git_url: https://git.bioconductor.org/packages/NanoTube
git_branch: RELEASE_3_22
git_last_commit: b78a412
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 05:23:17 UTC; biocbuild
Author: Caleb Class [cre, aut] (ORCID: <https://orcid.org/0000-0003-3130-3613>),
  Caiden Lukan [ctb]
Maintainer: Caleb Class <cclass@butler.edu>
