# Generated by roxygen2: do not edit by hand

export(deVolcano)
export(fgseaPostprocessing)
export(fgseaPostprocessingXLSX)
export(fgseaToLEdge)
export(gm_mean)
export(groupFGSEA)
export(groupedGSEAtoStackedReport)
export(limmaToFGSEA)
export(makeDiffExprFile)
export(makeNanoStringSetFromEset)
export(nanostringPCA)
export(negativeQC)
export(normalize_housekeeping)
export(normalize_pos_controls)
export(nsdiffToFGSEA)
export(positiveQC)
export(processNanostringData)
export(read_cpdb_sourceDBs)
export(read_cpdb_tab)
export(read_merge_rcc)
export(read_rcc)
export(read_sampleData)
export(remove_background)
export(runLimmaAnalysis)
export(untar_dirs)
export(unzip_dirs)
import(Biobase)
import(fgsea)
import(ggplot2)
import(limma)
import(reshape)
importFrom(methods,is)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,p.adjust)
importFrom(stats,prcomp)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,untar)
importFrom(utils,unzip)
importFrom(utils,write.table)
