# NanoTube

<a href="https://www.bioconductor.org/packages/NanoTube/">The NanoTube is on Bioconductor!</a>

NanoTube includes functions for the processing, quality control, 
analysis, and visualization of NanoString nCounter data. Analysis functions
include differential analysis and gene set analysis methods, as well as
postprocessing steps to help understand the results. Additional functions
are included to enable interoperability with other Bioconductor NanoString
data analysis packages.

Many more details can be found in the vignette (vignettes/NanoTube.Rmd).

If you use the NanoTube in your work, please cite:
Class CA, Lukan CJ, Bristow CA, Do KA. "Easy NanoString nCounter data analysis
with the NanoTube." Bioinformatics 2023; 39(1): btac762. https://doi.org/10.1093/bioinformatics/btac762