% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/NanoTube.R
\docType{package}
\name{NanoTube}
\alias{NanoTube}
\title{NanoTube}
\description{
A package for NanoString nCounter gene expression data processing,
analysis, and visualization.
}
